@@ -27,11 +27,42 @@
 #'
 #' @examples
 #' \donttest{
-#' library("DALEXtra")
+#'
+#'
+#' # # load packages and data
+#' library(h2o)
+#' library(DALEXtra)
+#'
+#' # data <- DALEX::titanic_imputed
+#'
+#' # init h2o
+#'  h2o.init()
+#'
+#' # stop h2o progress printing
+#'  h2o.no_progress()
+#'
+#' # split the data
+#' # h2o_split <- h2o.splitFrame(as.h2o(data))
+#' # train <- h2o_split[[1]]
+#' # test <- as.data.frame(h2o_split[[2]])
+#' # h2o automl takes target as factor
+#' # train$survived <- as.factor(train$survived)
+#'
+#' # fit a model
+#' # automl <- h2o.automl(y = "survived",
+#' #                   training_frame = train,
+#' #                    max_runtime_secs = 30)
+#'
+#'
+#' # create an explainer for the model
+#' # explainer <- explain_h2o(automl,
+#' #                        data = test,
+#' #                         y = test$survived,
+#' #                          label = "h2o")
+#'
+#'
 #' titanic_test <- read.csv(system.file("extdata", "titanic_test.csv", package = "DALEXtra"))
 #' titanic_train <- read.csv(system.file("extdata", "titanic_train.csv", package = "DALEXtra"))
-#' h2o::h2o.init()
-#' h2o::h2o.no_progress()
 #' titanic_h2o <- h2o::as.h2o(titanic_train)
 #' titanic_h2o["survived"] <- h2o::as.factor(titanic_h2o["survived"])
 #' titanic_test_h2o <- h2o::as.h2o(titanic_test)
@@ -45,7 +76,8 @@
 #' learn_rate = 0.001
 #' )
 #' explain_h2o(model, titanic_test[,1:17], titanic_test[,18])
-#' h2o::h2o.shutdown(prompt = FALSE)
+#'
+#' h2o.shutdown(prompt = FALSE)
 #' }
 #' @rdname explain_h2o
 #' @export
@@ -64,10 +96,21 @@ explain_h2o <-
            colorize = TRUE,
            model_info = NULL,
            type = NULL) {
+
     if (class(y) == "H2OFrame") {
-      y <- as.numeric(as.vector(y))
+      y <- as.vector(y)
     }
 
+    if (class(model) == "H2OAutoML") {
+      message("`model` argument is a H2OAutoML class object. model@leader will be extracted.\n")
+      model <- model@leader
+    }
+
+    if (class(data) == "H2OFrame") {
+      data <- as.data.frame(data)
+    }
+
+
     explain(
       model,
       data = data,
