@@ -12,6 +12,7 @@
 #' \item \code{keras} see more in \code{\link{explain_keras}}
 #' \item \code{mlr3} see more in \code{\link{explain_mlr3}}
 #' \item \code{xgboost} see more in \code{\link{explain_xgboost}}
+#' \item \code{tidymodels} see more in \code{\link{explain_tidymodels}}
 #' }
 #'
 #' @param X.model object - a model to be explained
@@ -208,6 +209,34 @@ yhat.xgb.Booster <- function(X.model, newdata, ...) {
 }
 
 
+#' @rdname yhat
+#' @export
+yhat.workflow <- function(X.model, newdata, ...) {
+  if ("tbl" %in% class(newdata)) {
+    newdata <- as.data.frame(newdata)
+  }
+    if (X.model$fit$fit$spec$mode == "classification") {
+      response <- as.matrix(predict(X.model, newdata, type = "prob"))
+      colnames(response) <- X.model$fit$fit$lvl
+      if (ncol(response) == 2) {
+        response <- response[,2]
+      }
+    }
+    else if (X.model$fit$fit$spec$mode == "regression") {
+      pred <- predict(X.model, newdata)
+      response <- pred$.pred
+    }
+    else {
+      stop("Mode specification has to be either classification or regression")
+    }
+
+
+  response
+
+}
+
+
+
 normalize_h2o_names <- function(names) {
   ret <- sapply(names, FUN = function(x) {
     tmp <- strsplit(x, "p")
